PALM-meteo: palmmeteo_stdplugins.meteo.SomeMeteoPlugin.Provides Class Reference

PALM-meteo

Static Public Attributes | List of all members
palmmeteo_stdplugins.meteo.SomeMeteoPlugin.Provides Class Reference

## Static Public Attributes
list | meteo_vars = ['tas', 'pa']

## Member Data Documentation

## ◆ meteo_vars

list palmmeteo_stdplugins.meteo.SomeMeteoPlugin.Provides.meteo_vars = ['tas', 'pa']
| static

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/meteo.py